Attributes
**********

.. currentmodule:: ModernGL

.. autoclass:: Attribute
	:members: name, location, dimension, array_length

.. autoclass:: AttributeMap

	.. automethod:: __getitem__(key) -> Attribute

.. toctree::
	:maxdepth: 4
